@@ -1,2 +1,5 @@
 def write(*text):
-	print("".join(text), end="")
\ No newline at end of file
+	print("".join(text), end="")
+
+def read():
+	return input()
\ No newline at end of file
